#!/usr/bin/env python3
from subprocess import run,PIPE
from sys import argv
import numpy as np
import json

def Qcore_calc(CalcType):
    p = run(['qcore','-n','1','-f','json',CalcType],stdout=PIPE, stderr=PIPE, universal_newlines=True)
    properties = [ 'energy','gradient','frequencies','normal_modes','gibbs_free_energy','zero_point_energy']
    values = []
    if len(p.stdout) > 0:
        for x in properties: 
            if x in json.loads(p.stdout)['my_result']:
                if x == 'normal_modes':
                    imag = np.array(json.loads(p.stdout)['my_result'][x][0])
                    values.append( imag / np.linalg.norm(imag) )
                else:
                    values.append( np.array(json.loads(p.stdout)['my_result'][x]) )
            else:
                values.append(np.zeros(1))
    else:
        print(p.stderr)
        exit()
    return values 

if __name__ == '__main__':
    e, grad, freq, imag_nm, gibbs, zpe = Qcore_calc(argv[1])
    print("Energy=",e)
    if len(grad) == 1: exit()
    print("Gradient:")
    for atom in grad:
        for x in atom:
            print(x)
    print("Freq:")
    for x in freq: print(x * 219474.6552)
    print("Gibbs free energy:",gibbs)
    print("ZPE:",zpe)
    if 'thermo' in argv[1]: print("== QCORE DONE ==")
